package types

import "p78git.ddns.net/svi/libtui/alias"

// ICell -- ячейка отображения на экране
type ICell interface {
	// Pos -- позиция ячейка на экране
	Pos() (alias.PosX, alias.PosY)
	// SetPos -- устанавливает позицию литеры на экране
	SetPos(alias.PosX, alias.PosY)
	// Style -- стиль ячейки
	Style() alias.Style
	// Lit -- литера ячейки
	Lit() alias.Lit
	// SetLit -- устанавливает литеру для отображения
	SetLit(alias.Lit)
	// BgColor -- возвращает цвет фона
	BgColor() alias.Color
	// BgColorSet -- устанавливает цвет фона
	BgColorSet(alias.Color)
	// FgColor -- возвращает передний цвет
	FgColor()alias.Color
	// FgColorSet -- устанавливает передний фон
	FgColorSet(alias.Color)
	// SetStyle -- устанавливает стиль ячейки
	SetStyle(alias.Style)
}
